@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ContentHandler.cpp 8279 2008-06-13 00:36:19Z diegoe $
+ *  $Id$
  */
 
 #include "mozilla-config.h"
@@ -88,7 +88,7 @@ GContentHandler::Show (nsIHelperAppLauncher *aLauncher,
 		       nsISupports *aContext,
 		       PRUint32 aReason)
 {
-        nsRefPtr<GContentHandler> kungFuDeathGrip(this);
+	nsRefPtr<GContentHandler> kungFuDeathGrip(this);
 
 	nsresult rv;
 	EphyEmbedSingle *single;
@@ -131,7 +131,7 @@ GContentHandler::Show (nsIHelperAppLauncher *aLauncher,
 
 /* nsILocalFile promptForSaveToFile (in nsISupports aWindowContext, in wstring aDefaultFile, in wstring aSuggestedFileExtension); */
 NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
-				    nsIHelperAppLauncher *aLauncher,			    
+				    nsIHelperAppLauncher *aLauncher,
 				    nsISupports *aWindowContext,
 				    const PRUnichar *aDefaultFile,
 				    const PRUnichar *aSuggestedFileExtension,
@@ -154,9 +154,9 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 	}
 	nsCOMPtr<nsIDOMWindow> parentDOMWindow (do_GetInterface (aWindowContext));
 
-        AutoModalDialog modalDialog (parentDOMWindow, PR_FALSE);
-        if (!modalDialog.ShouldShow ())
-          return NS_ERROR_FAILURE;
+	AutoModalDialog modalDialog (parentDOMWindow, PR_FALSE);
+	if (!modalDialog.ShouldShow ())
+		return NS_ERROR_FAILURE;
 
 	GtkWindow *parentWindow = modalDialog.GetParent ();
 
@@ -165,7 +165,11 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 					CONF_STATE_SAVE_DIR,
 					EPHY_FILE_FILTER_ALL);
 	gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
-	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), defaultFile.get());
+	/* Remove leading dots */
+	const char *fname = defaultFile.get();
+	while (*fname == '.') fname++;
+
+	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), fname);
 
 	if (parentWindow)
 	{
@@ -465,7 +469,7 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 	}
 #endif /* HAVE_GECKO_1_9 */
 
-        nsRefPtr<GContentHandler> kungFuDeathGrip(this);
+	nsRefPtr<GContentHandler> kungFuDeathGrip(this);
 
 	if (mAction == CONTENT_ACTION_OPEN)
 	{
@@ -485,18 +489,19 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 	}
 
 #ifdef HAVE_GECKO_1_9
-        /* We have to do this work down here because the external helper app modifies the
-         * value after calling SaveToDisk.
-         */
+	/* We have to do this work down here because the external helper app 
+	 * modifies the value after calling SaveToDisk.
+	 */
 	nsHandlerInfoAction action;
 	if (mAction == CONTENT_ACTION_DOWNLOAD) {
 		action = EPHY_ACTION_BROWSE_TO_FILE;
 
-                /* This won't be able to transport the activation time so we cannot
-                * do startup notification, but it's the best that was available
-                */
-                mimeInfo->SetPreferredAction (action);
-        }
+		/* This won't be able to transport the activation time so we 
+		 * cannot do startup notification, but it's the best that was 
+		 * available
+		 */
+		mimeInfo->SetPreferredAction (action);
+	}
 #endif
 
 	return NS_OK;
