@@ -16,13 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ContentHandler.h 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id$
  */
 
 #ifndef CONTENT_HANDLER_H
 #define CONTENT_HANDLER_H
 
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <gio/gio.h>
 
 #include <nsCOMPtr.h>
 #include <nsIFile.h>
@@ -59,9 +59,9 @@ class GContentHandler : public nsIHelperAppLauncherDialog
 	virtual ~GContentHandler();
 
 	NS_METHOD MIMEDoAction ();
-	ContentAction mAction;
   private:
 
+        static void ResponseCallback (GtkWidget*, int, GContentHandler*);
 	NS_METHOD Init ();
 
 	NS_METHOD MIMEInitiateAction ();
@@ -70,12 +70,13 @@ class GContentHandler : public nsIHelperAppLauncherDialog
 	nsCOMPtr<nsIHelperAppLauncher> mLauncher;
 	nsCOMPtr<nsISupports> mContext;
 
-	GnomeVFSMimeApplication *mHelperApp;
+	GAppInfo *mHelperApp;
 	EphyMimePermission mPermission;
 
 	nsCString mUrl;
 	nsCString mMimeType;
 	PRUint32 mUserTime;
+	ContentAction mAction;
 };
 
 #endif /* CONTENT_HANDLER_H */
