@@ -16,15 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: GtkNSSDialogs.h 7803 2007-12-23 22:00:12Z chpe $
+ * $Id$
  */ 
 
 #ifndef GTKNSSDIALOGS_H
 #define GTKNSSDIALOGS_H 1
 
-#ifdef HAVE_GECKO_1_9
-#include <nsIBadCertListener2.h>
-#else
+#ifdef HAVE_NSIBADCERTLISTENER_H
 #include <nsIBadCertListener.h>
 #endif
 #include <nsICertificateDialogs.h>
@@ -42,9 +40,7 @@ class nsIPKCS11Slot;
 #define GTK_NSSDIALOGS_CLASSNAME  "Gtk NSS Dialogs"
 
 class GtkNSSDialogs : public nsICertificateDialogs,
-#ifdef HAVE_GECKO_1_9
-                      public nsIBadCertListener2,
-#else
+#ifdef HAVE_NSIBADCERTLISTENER_H
                       public nsIBadCertListener,
 #endif
 		      public nsITokenPasswordDialogs,
@@ -54,9 +50,7 @@ class GtkNSSDialogs : public nsICertificateDialogs,
   public:
     NS_DECL_ISUPPORTS
     NS_DECL_NSICERTIFICATEDIALOGS
-#ifdef HAVE_GECKO_1_9
-    NS_DECL_NSIBADCERTLISTENER2
-#else
+#ifdef HAVE_NSIBADCERTLISTENER_H
     NS_DECL_NSIBADCERTLISTENER
 #endif
     NS_DECL_NSITOKENPASSWORDDIALOGS
