@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-dialog.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id$
  */
 
 #include "config.h"
@@ -29,15 +29,8 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkradiobutton.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtkeditable.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtksizegroup.h>
-#include <gtk/gtkdialog.h>
-#include <glade/glade-xml.h>
+#include <gtk/gtk.h>
+#include <glade/glade.h>
 
 enum
 {
