@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-gui.c 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id$
  */
 
 #include "config.h"
@@ -28,18 +28,10 @@
 #include <ctype.h>
 #include <string.h>
 #include <glib/gi18n.h>
+#include <gdk/gdk.h>
 #include <gdk/gdkx.h>
+#include <gtk/gtk.h>
 #include <libgnome/gnome-help.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkmessagedialog.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktoolbar.h>
-#include <gtk/gtktogglebutton.h>
 
 #include <unistd.h>
 
