@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-spell-check.c,v 1.2.2.2 2006/09/13 11:48:44 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
@@ -43,7 +43,7 @@ enum
 	LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL];
+/* static guint signals[LAST_SIGNAL]; */
 static GObjectClass *parent_class;
 
 /* Helper functions */
@@ -182,8 +182,6 @@ ephy_spell_check_check_word (EphySpellCheck *speller,
 
 	g_return_val_if_fail (word != NULL, -1);
 
-	g_print ("ephy_spell_check_check_word: '%s'\n", word);
-
 	if (priv->dict == NULL)
 		return FALSE;
 
