@@ -53,8 +53,7 @@ struct _EphyLocationEntryPrivate
 	GdkColor secure_bg_colour;
 	GdkColor secure_fg_colour;
 
-	GtkCellRenderer *extracell;
-	GRegex *regex;
+	GSList *search_terms;
 
 	char *before_completion;
 	char *saved_text;
@@ -92,11 +91,16 @@ static void ephy_location_entry_class_init (EphyLocationEntryClass *klass);
 static void ephy_location_entry_init (EphyLocationEntry *le);
 static gboolean ephy_location_entry_reset_internal (EphyLocationEntry *, gboolean);
 
+static void textcell_data_func (GtkCellLayout *cell_layout,
+			GtkCellRenderer *cell,
+			GtkTreeModel *tree_model,
+			GtkTreeIter *iter,
+			gpointer data);
 static void extracell_data_func (GtkCellLayout *cell_layout,
-				GtkCellRenderer *cell,
-				GtkTreeModel *tree_model,
-				GtkTreeIter *iter,
-				gpointer data);
+			GtkCellRenderer *cell,
+			GtkTreeModel *tree_model,
+			GtkTreeIter *iter,
+			gpointer data);
 
 static GObjectClass *parent_class = NULL;
 
@@ -160,10 +164,6 @@ ephy_location_entry_style_set (GtkWidget *widget,
 	}
 
 	title_fg_colour = widget->style->text[GTK_STATE_INSENSITIVE];
-	g_object_set (entry->priv->extracell, 
-			"foreground-gdk", &title_fg_colour,
-			"foreground-set", TRUE,
-			NULL);
 
 	settings = gtk_settings_get_for_screen (gtk_widget_get_screen (widget));
 	g_object_get (settings, "gtk-theme-name", &theme, NULL);
@@ -203,6 +203,17 @@ ephy_location_entry_style_set (GtkWidget *widget,
 	ephy_location_entry_set_secure (entry, priv->secure);
 }
 
+inline static void
+free_search_terms (GSList *search_terms)
+{
+	GSList *iter;
+	
+	for (iter = search_terms; iter != NULL; iter = iter->next)
+		g_regex_unref ((GRegex*)iter->data);
+	
+	g_slist_free (search_terms);
+}
+
 static void
 ephy_location_entry_finalize (GObject *object)
 {
@@ -216,10 +227,10 @@ ephy_location_entry_finalize (GObject *object)
 		g_object_unref (priv->favicon);
 	}
 	
-	if (priv->regex)
+	if (priv->search_terms)
 	{
-		g_regex_unref (priv->regex);
-		priv->regex = NULL;
+		free_search_terms (priv->search_terms);
+		priv->search_terms = NULL;
 	}
 
 	parent_class->finalize (object);
@@ -348,42 +359,109 @@ editable_changed_cb (GtkEditable *editable,
 		priv->can_redo = FALSE;
 	}	
 	
-	if (priv->regex)
+	if (priv->search_terms)
 	{
-		g_regex_unref (priv->regex);
-		priv->regex = NULL;
+		free_search_terms (priv->search_terms);
+		priv->search_terms = NULL;
 	}
-	
+
 	text = gtk_entry_get_text (GTK_ENTRY (editable));
 
+	/*
+	 * user is specifying a regular expression, so we will
+	 * have only one search term
+	 */
 	if (g_str_has_prefix (text, "re:"))
+	{
+		GRegex *regex;
 		pattern = g_strdup (text+3);
+		regex = g_regex_new (pattern,
+				     G_REGEX_CASELESS | G_REGEX_OPTIMIZE,
+				     G_REGEX_MATCH_NOTEMPTY, NULL);
+		priv->search_terms = g_slist_append (priv->search_terms, regex);
+		g_free (pattern);
+	}
 	else
-		pattern = g_regex_escape_string (text, -1);
+	{
+		const char *current;
+		const char *ptr;
+		char *tmp;
+		char *term;
+		GRegex *term_regex;
+		GRegex *quote_regex;
+		gint count;
+		gboolean inside_quotes = FALSE;
 
-	priv->regex = g_regex_new (pattern, 
-				G_REGEX_CASELESS | G_REGEX_OPTIMIZE, 
-				G_REGEX_MATCH_NOTEMPTY, NULL);
+		quote_regex = g_regex_new ("\"", G_REGEX_OPTIMIZE,
+					   G_REGEX_MATCH_NOTEMPTY, NULL);
+		
+		/*
+		 * This code loops through the string using pointer arythmetics.
+		 * Although the string we are handling may contain UTF-8 chars
+		 * this works because only ASCII chars affect what is actually
+		 * copied from the string as a search term.
+		 */
+		for (count = 0, current = ptr = text; ptr[0] != '\0'; ptr++, count++)
+		{
+			/*
+			 * If we found a double quote character; we will 
+			 * consume bytes up until the next quote, or
+			 * end of line;
+			 */
+			if (ptr[0] == '"')
+				inside_quotes = !inside_quotes;
 
-	g_free (pattern);
+			/*
+			 * If we found a space, and we are not looking for a
+			 * closing double quote, or if the next char is the
+			 * end of the string, append what we have already as
+			 * a search term.
+			 */
+			if (((ptr[0] == ' ') && (!inside_quotes)) || ptr[1] == '\0')
+			{
+				/*
+				 * We special-case the end of the line because
+				 * we would otherwise not copy the last character
+				 * of the search string, since the for loop will
+				 * stop before that.
+				 */
+				if (ptr[1] == '\0')
+					count++;
+				
+				/*
+				 * remove quotes, and quote any regex-sensitive
+				 * characters
+				 */
+				tmp = g_regex_escape_string (current, count);
+				term = g_regex_replace (quote_regex, tmp, -1, 0,
+							"", G_REGEX_MATCH_NOTEMPTY, NULL);
+				g_strstrip (term);
+				g_free (tmp);
+
+				/* we don't want empty search terms */
+				if (term[0] != '\0')
+				{
+					term_regex = g_regex_new (term,
+								  G_REGEX_CASELESS | G_REGEX_OPTIMIZE,
+								  G_REGEX_MATCH_NOTEMPTY, NULL);
+					priv->search_terms = g_slist_append (priv->search_terms, term_regex);
+				}
+				g_free (term);
+
+				 /* count will be incremented by the for loop */
+				count = -1;
+				current = ptr + 1;
+			}
+		}
+
+		g_regex_unref (quote_regex);
+	}
 
 	update_favicon (entry);
 
 	g_signal_emit (entry, signals[USER_CHANGED], 0);
 }
 
-static gboolean
-entry_button_press_cb (GtkWidget *entry, GdkEventButton *event, EphyLocationEntry *le)
-{
-	if (event->button == 1 && event->type == GDK_2BUTTON_PRESS)
-	{
-		ephy_location_entry_activate (le);
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
 static gboolean
 entry_key_press_cb (GtkEntry *entry,
 		    GdkEventKey *event,
@@ -911,8 +989,6 @@ ephy_location_entry_construct_contents (EphyLocationEntry *entry)
 				G_CALLBACK (entry_key_press_after_cb), entry);
 	g_signal_connect_after (priv->icon_entry->entry, "activate",
 				G_CALLBACK (entry_activate_after_cb), entry);
-	g_signal_connect (priv->icon_entry->entry, "button-press-event",
-			  G_CALLBACK (entry_button_press_cb), entry);
 	g_signal_connect (priv->icon_entry->entry, "changed",
 			  G_CALLBACK (editable_changed_cb), entry);
 	g_signal_connect (priv->icon_entry->entry, "drag-motion",
@@ -936,7 +1012,7 @@ ephy_location_entry_init (EphyLocationEntry *le)
 	p->user_changed = FALSE;
 	p->block_update = FALSE;
 	p->saved_text = NULL;
-	p->regex = NULL;
+	p->search_terms = NULL;
 	
 	ephy_location_entry_construct_contents (le);
 
@@ -963,14 +1039,111 @@ cursor_on_match_cb  (GtkEntryCompletion *completion,
 			    &item, -1);
 	entry = gtk_entry_completion_get_entry (completion);
 
+	/* Prevent the update so we keep the highlight from our input.
+	 * See textcell_data_func().
+	 */
+	le->priv->block_update = TRUE;
 	gtk_entry_set_text (GTK_ENTRY (entry), item);
 	gtk_editable_set_position (GTK_EDITABLE (entry), -1);
+	le->priv->block_update = FALSE;
 
 	g_free (item);
 
 	return TRUE;
 }
 
+static void
+textcell_data_func (GtkCellLayout *cell_layout,
+			GtkCellRenderer *cell,
+			GtkTreeModel *tree_model,
+			GtkTreeIter *iter,
+			gpointer data)
+{
+	EphyLocationEntryPrivate *priv;
+	PangoAttrList *list;
+	PangoAttribute *att;
+	GMatchInfo *match;
+
+	int start, end;
+
+	char *ctext;
+	char *title;
+	char *url;
+
+	GtkStyle *style;
+	GdkColor color;
+
+	GValue text = { 0, };
+
+	priv = EPHY_LOCATION_ENTRY (data)->priv;
+	gtk_tree_model_get (tree_model, iter,
+			priv->text_col, &title,
+			priv->url_col, &url,
+			-1);
+
+	list = pango_attr_list_new ();
+
+	if (url)
+	{
+		ctext = g_strdup_printf ("%s\n%s", title, url);
+
+		style = gtk_widget_get_style (priv->icon);
+		color = style->text[GTK_STATE_INSENSITIVE];
+
+		att = pango_attr_foreground_new
+			(color.red, color.green, color.blue);
+		att->start_index = strlen (title)+1;
+
+		pango_attr_list_insert (list, att);
+	}
+	else
+	{
+		ctext = title;
+	}
+
+	if (priv->search_terms)
+	{
+		GSList *iter;
+		GRegex *regex;
+
+		for (iter = priv->search_terms; iter != NULL; iter = iter->next)
+		{
+			regex = (GRegex*) iter->data;
+			g_regex_match (regex, ctext, G_REGEX_MATCH_NOTEMPTY, &match);
+
+			while (g_match_info_matches (match))
+			{
+				g_match_info_fetch_pos (match, 0, &start, &end);
+
+				att = pango_attr_weight_new (PANGO_WEIGHT_BOLD);
+				att->start_index = start;
+				att->end_index = end;
+
+				pango_attr_list_insert (list, att);
+				g_match_info_next (match, NULL);
+			}
+
+			g_match_info_free (match);
+			match = NULL;
+		}
+
+	}
+
+	g_object_set (G_OBJECT (cell),
+			"attributes", list,
+			NULL);
+
+	g_value_init (&text, G_TYPE_STRING);
+	g_value_take_string (&text, ctext);
+	g_object_set_property (G_OBJECT (cell), "text", &text);
+	g_value_unset (&text);
+
+	pango_attr_list_unref (list);
+
+	g_free (title);
+	g_free (url);
+}
+
 static void
 extracell_data_func (GtkCellLayout *cell_layout,
 			GtkCellRenderer *cell,
@@ -978,25 +1151,23 @@ extracell_data_func (GtkCellLayout *cell_layout,
 			GtkTreeIter *iter,
 			gpointer data)
 {
-	char *cdata;
-	GValue visible = { 0, };
-	GValue text = { 0, };
 	EphyLocationEntryPrivate *priv;
+	gboolean is_bookmark = FALSE;
+	GValue visible = { 0, };
 
 	priv = EPHY_LOCATION_ENTRY (data)->priv;
+	gtk_tree_model_get (tree_model, iter,
+			priv->extra_col, &is_bookmark,
+			-1);
 
-	gtk_tree_model_get (tree_model, iter, priv->extra_col, &cdata, -1);
+	if (is_bookmark)
+		g_object_set (G_OBJECT (cell),
+				"stock-id", EPHY_STOCK_BOOKMARK,
+				NULL);
 
-	g_value_init (&text, G_TYPE_STRING);
 	g_value_init (&visible, G_TYPE_BOOLEAN);
-	
-	g_value_take_string (&text, cdata);
-	g_value_set_boolean (&visible, (cdata != NULL));
-
-	g_object_set_property (G_OBJECT (cell), "text", &text);
+	g_value_set_boolean (&visible, is_bookmark);
 	g_object_set_property (G_OBJECT (cell), "visible", &visible);
-	
-	g_value_unset (&text);
 	g_value_unset (&visible);
 }
 
@@ -1027,7 +1198,7 @@ ephy_location_entry_set_completion (EphyLocationEntry *le,
 	EphyLocationEntryPrivate *priv = le->priv;
 	GtkTreeModel *sort_model;
 	GtkEntryCompletion *completion;
-	GtkCellRenderer *cell, *iconcell;
+	GtkCellRenderer *cell, *iconcell, *extracell;
 
 	le->priv->text_col = text_col;
 	le->priv->action_col = action_col;
@@ -1069,19 +1240,18 @@ ephy_location_entry_set_completion (EphyLocationEntry *le,
 				    cell, TRUE);
 	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (completion),
 				       cell, "text", text_col);
+	gtk_cell_renderer_text_set_fixed_height_from_font (GTK_CELL_RENDERER_TEXT (cell), 2);
 
-	le->priv->extracell = gtk_cell_renderer_text_new ();
-	g_object_set (le->priv->extracell, 
-			"ellipsize", PANGO_ELLIPSIZE_END,
-			"ellipsize-set", TRUE,
-			"alignment", PANGO_ALIGN_LEFT,
-			NULL);
-
-	gtk_cell_layout_pack_end (GTK_CELL_LAYOUT (completion),
-				  le->priv->extracell, TRUE);
-	
 	gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (completion),
-					le->priv->extracell, extracell_data_func, 
+					cell, textcell_data_func,
+					le,
+					NULL);
+
+	extracell = gtk_cell_renderer_pixbuf_new ();
+	gtk_cell_layout_pack_end (GTK_CELL_LAYOUT (completion),
+				    extracell, FALSE);
+	gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (completion),
+					extracell, extracell_data_func,
 					le,
 					NULL);
 
@@ -1329,10 +1499,20 @@ ephy_location_entry_set_lock_tooltip (EphyLocationEntry *entry,
 	gtk_widget_set_tooltip_text (priv->lock_ebox, tooltip);
 }
 
-GRegex *
-ephy_location_entry_get_regex (EphyLocationEntry *entry)
+/**
+ * ephy_location_entry_get_search_terms:
+ * @entry: an #EphyLocationEntry widget
+ *
+ * Return the internal #GSList containing the search terms as #GRegex
+ * instances, formed in @entry on user changes.
+ *
+ * Return value: the internal #GSList
+ *
+ **/
+GSList *
+ephy_location_entry_get_search_terms (EphyLocationEntry *entry)
 {
 	EphyLocationEntryPrivate *priv = entry->priv;
 	
-	return priv->regex;
+	return priv->search_terms;
 }
