@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmarks-export.c 7869 2008-01-15 07:56:31Z xan $
+ *  $Id$
  */
 
 #include "config.h"
@@ -233,7 +233,7 @@ write_rdf (EphyBookmarks *bookmarks,
 			char *scheme;
 			char *host_name;
 			
-			scheme = g_uri_get_scheme (url);
+			scheme = g_uri_parse_scheme (url);
 			host_name = ephy_string_get_host_name (url);
 			link = g_strconcat (scheme,
 					    "://",
@@ -304,7 +304,7 @@ write_rdf (EphyBookmarks *bookmarks,
 			char *scheme;
 			char *host_name;
 
-			scheme = g_uri_get_scheme (url);
+			scheme = g_uri_parse_scheme (url);
 			host_name = ephy_string_get_host_name (url);
 
 			link = g_strconcat (scheme,
