@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-topics-entry.h 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_TOPICS_ENTRY_H
@@ -23,7 +23,7 @@
 
 #include "ephy-bookmarks.h"
 
-#include <gtk/gtkentry.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
